def factorial(n):
    f = 1
    for i in range(1, n + 1):
        f *= i
    return f


def permutation(n):
    return factorial(n)


def compination(n, k):
    return factorial(n) / (factorial(k) * factorial(n - k))

def binkof(n,k):
    return factorial(n)/(factorial(k)*factorial(n-k))

def gamma(n):
    return factorial(n-1)

def summaf(n):
    h=0
    for i in range(n+1):
        if i!=0:
            h+=factorial(i)
    return h




if __name__ == '__main__':
    from .strop import *

else:
    from mynewlib1.str_op.strop import *


def test_single_number(comments=False):
    if comments:
        print('test factorial...')
    assert Task('5')==5

    if comments:
        print('factorial completed')

test_single_number()
'''
def test_addition(self):
        task = Task('2 + 3')
        self.assertEqual(task.compute(), 5.0)

    def test_subtraction(self):
        task = Task('5 - 2')
        self.assertEqual(task.compute(), 3.0)

    def test_multiplication(self):
        task = Task('3 * 4')
        self.assertEqual(task.compute(), 12.0)

    def test_division(self):
        task = Task('10 / 2')
        self.assertEqual(task.compute(), 5.0)

    def test_combined_operations(self):
        task = Task('2 + 3 * 4')
        self.assertEqual(task.compute(), 14.0)  # 3 * 4 = 12, 2 + 12 = 14

    def test_mixed_operations(self):
        task = Task('10 - 2 + 3 * 4 / 2')
        self.assertEqual(task.compute(), 14.0)  # 3 * 4 / 2 = 6, 10 - 2 + 6 = 14


if __name__ == '__main__':
    unittest.main()
'''


class Task:
    def __init__(self, formula):
        self.formula = formula

    def compute(self):
        operators = ['+', '-', '*', '/']

        # Пробуем получить наиболее приоритетный оператор
        for op in operators:
            if op in self.formula:
                index = self.formula.index(op)

                # Разделяем на левую и правую часть
                left = Task(self.formula[:index].strip())  # Убираем лишние пробелы
                right = Task(self.formula[index + 1:].strip())

                match op:
                    case '+':
                        return left.compute() + right.compute()
                    case '-':
                        return left.compute() - right.compute()
                    case '*':
                        return left.compute() * right.compute()
                    case '/':
                        return left.compute() / right.compute()

        # Если нет операторов, просто возвращаем число
        return float(self.formula)




from setuptools import setup, find_packages

setup(
    name="mynewlib1",
    version="1.0.18",
    test_suite='tests',
    author="Romitsina Spelov",
    author_email="romitsina.a.r@gmail.com",
    description="Библиотека для работы с факториалами и вычисления чисел из формул типа str",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/Anromit/mylib/tree/main/mylib",
    packages=find_packages(),
    license='example',
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.12",
)





if __name__ == '__main__':
    from .operations import *

else:
    from mynewlib1.math.operations import *





def test_factorial(comments=False):
    if comments:
        print('test factorial...')
    assert factorial(3) == 6

    if comments:
        print('factorial completed')

def test_permutation(comments=False):
    if comments:
        print('test permutation...')
    assert permutation(4) == 24

    if comments:
        print('permutation completed')

def test_compination(comments=False):
    if comments:
        print('test compination...')
    assert compination(5,3) == 10

    if comments:
        print('compination completed')

def test_binkof(comments=False):
    if comments:
        print('test binkof...')
    assert binkof(100,2) == 4950

    if comments:
        print('binkof completed')

def test_gamma(comments=False):
    if comments:
        print('test gamma...')
    assert gamma(4) == 6

    if comments:
        print('gamma completed')

def test_summaf(comments=False):
    if comments:
        print('test 5...')
    assert summaf(3) == 9

    if comments:
        print('summaf completed')

test_factorial()
test_permutation()
test_compination()
test_binkof()
test_gamma()
test_summaf()




